Conversational Space Map App
****************************

|PyPI version| |PyPI status| |PyPI license| |PyPI pyversions| |CI| |Code style|


.. |PyPI status| image:: https://img.shields.io/pypi/status/ConversationalSpaceMapApp
   :alt: PyPI - Status
.. |PyPI version| image:: https://img.shields.io/pypi/v/ConversationalSpaceMapApp
   :alt: PyPI - Version
.. |PyPI license| image:: https://img.shields.io/pypi/l/ConversationalSpaceMapApp
   :alt: PyPI - License
.. |PyPI pyversions| image:: https://img.shields.io/pypi/pyversions/ConversationalSpaceMapApp.svg
   :target: https://pypi.python.org/pypi/ConversationalSpaceMapApp/
.. |CI| image:: https://codecov.io/gh/manuelbieri/ConversationalSpaceMapApp/graph/badge.svg?token=VD3LEELSOB 
   :target: https://codecov.io/gh/manuelbieri/ConversationalSpaceMapApp
.. |Code style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :alt: Code style


Generate conversational space maps for interview transcripts generated with `aTrain <https://github.com/JuergenFleiss/aTrain>`_, inspired by Saunders et al. (2023, pp. 458-460).

.. image:: https://raw.githubusercontent.com/manuelbieri/ConversationalSpaceMapApp/refs/heads/master/docs/images/Screenshot.png
   :width: 95%
   :alt: App screenshot
   :align: center

Quickstart
============================

Installation - PyPi
----------------------------

Note: This quickstart guide assumes that you have already installed Python.

1. Install via terminal

.. code-block:: bash

    $ pip install ConversationalSpaceMapApp

2. Run the app in the terminal.

.. code-block:: bash

    $ csm-run


Installation - Executable
----------------------------------------

Go to the `download-page <https://github.com/manuelbieri/ConversationalSpaceMapApp/releases/latest>`_ and download the installer matching your system.

Note: You will get a warning while installing the app because it is not signed with a certificate.

References
============================
**Saunders, Mark, Philip Lewis, and Adrian Thornhill**, *Research methods for business students*, 9 ed., Harlow, England: Pearson, 2023.
